@@ -332,7 +332,7 @@ network.estimation <- function(
 
 #' @noRd
 # Argument errors ----
-# Updated 13.08.2023
+# Updated 19.08.2023
 network.estimation_errors <- function(data, n, network.only, verbose)
 {
   
@@ -358,8 +358,8 @@ network.estimation_errors <- function(data, n, network.only, verbose)
   length_error(verbose, 1, "network.estimation")
   typeof_error(verbose, "logical", "network.estimation")
   
-  # Return data in case of tibble
-  return(data)
+  # Return usable data in case of tibble
+  return(usable_data(data, verbose))
   
 }
 
